autowisp.tests.h5_test_case module — AutoWISP documentation

# autowisp.tests.h5_test_case module

## Class Inheritance Diagram

Define class to compare groups in DR files.

class autowisp.tests.h5_test_case.H5TestCase(methodName='runTest')

  Bases: `AutoWISPTestCase`

  Add assert for comparing groups in HDF5 files.

  assert_groups_match(dr_fname1, dr_fname2, group_name, ignore)

    Check if two DR files have the same groups.

  run_step_test(step_name, inputs, compare, *, ignore=None, output_type='DR')

    Run a test of a single step that updates the DR files.

    Parameters:

      - step_name (str) – The name of the step being tested

      - inputs ([]) – List of the directories or files needed by the step. The first entry (with full path added) is passed as input to the step.

      - compare ([]) – List of the HDF5 groups to compare in order to ensure the step produced correct results,

      - ignore (callable) – Function that returns true on any dataset or group in the HDF5 file that should not be compared when it is under the groups specified in `compare`

      - tput_type (str) – The type of output files produced by the step (i.e. whic files should be compared),